providers

package
v0.0.0-...-d726861 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jun 6, 2025 License: MIT Imports: 3 Imported by: 0

Documentation

Index

Constants

const CloudflareDNSRecordTimeout = time.Minute * 30

CloudflareDNSRecordTimeout is how long we wait after creating the challenge until we delete it

Variables

This section is empty.

Functions

This section is empty.

Types

type CloudflareWorker

type CloudflareWorker struct {
	// contains filtered or unexported fields
}

CloudflareWorker provider that communicates with a deployed Cloudflare worker that then creates and removes the challenges from DNS

This allows a seperation of the apikey for free plans, letting certproxy issue challenges to Cloudflare without needing a full edit zone apikey

func NewCloudflareWorker

func NewCloudflareWorker(db *bbolt.DB, apikey string, endpoint string) *CloudflareWorker

NewCloudflareWorker is returned and then should be initalized

func (*CloudflareWorker) CreateChallenge

func (cw *CloudflareWorker) CreateChallenge() error

CreateChallenge in Cloudflare DNS that by default expires in CloudflareDNSRecordTimeout

func (*CloudflareWorker) Initalize

func (cw *CloudflareWorker) Initalize() error

Initalize the CloudflareWorker provider, recover database, and finish in-progress challenges

Jump to